/* Sistemas Integrados TECNISA
   Planejamento Alimentao Industrial

Nome:  7791_PLASTPS_INTEGRA_RECEITA_REGRAS.SQL

Descrio: Realiza a reviso de receitas.

Parmetros de entrada:
   P_NRLISTA    => Nmero da lista onde est inserida as filiais agregadas
   P_CDPRATOINI => Cdigo do prato inicial
   P_CDPRATOFIN => Cdigo do prato final
   P_TIPOIMPORT => Tipo de importao (Acrescentar 'A', Sobrepor 'S')

Criao:
Leonardo Leo - 06/06/2006 */

IF EXISTS (SELECT * FROM sysobjects O, sysusers U
          WHERE
            o.name = 'INTEGRA_RECEITA_REGRAS' and
            type = 'P'                  and
            u.uid = o.uid               and
            u.name = USER)
   DROP PROCEDURE INTEGRA_RECEITA_REGRAS;
GO

CREATE PROCEDURE INTEGRA_RECEITA_REGRAS
   @P_NRLISTA    VARCHAR(10),
   @P_CDPRATOINI VARCHAR(20),
   @P_CDPRATOFIN VARCHAR(20),
   @P_TIPOIMPORT VARCHAR(1)
AS
   DECLARE @V_QTLIQUIDA NUMERIC(15,6);
   DECLARE @V_QTBRUTA   NUMERIC(15,6);
   DECLARE @V_QTCALC    NUMERIC(15,6);
   DECLARE @V_QTCALCNUT NUMERIC(15,6);
   DECLARE @V_CONTPROD  NUMERIC;
   DECLARE @V_CONTRECEF NUMERIC;

   DECLARE @CUR_PRATO  VARCHAR(10);
   DECLARE @CUR_FILIAL VARCHAR(4);
   DECLARE @V_IDQTLIQUBRUT VARCHAR(1);

   DECLARE @C_PRODREGRAS_CDPRATO      VARCHAR(10);
   DECLARE @C_PRODREGRAS_CDPRODUTO    VARCHAR(10);
   DECLARE @C_PRODREGRAS_QTPRODPRAT   NUMERIC(15,6);
   DECLARE @C_PRODREGRAS_VRPEFATCOCPR NUMERIC(15,6);
   DECLARE @C_PRODREGRAS_VRPEFATCORPR NUMERIC(15,6);
   DECLARE @C_PRODREGRAS_HRTEMPPREPPR VARCHAR(5);
   DECLARE @C_PRODREGRAS_SGUNIDADE    VARCHAR(10);
   DECLARE @C_PRODREGRAS_QTUNIDESTPR  NUMERIC(15,6);
   DECLARE @C_PRODREGRAS_QTBRUTAPR    NUMERIC(15,6);
   DECLARE @C_PRODREGRAS_IDPRODBASEPR VARCHAR(1);
   DECLARE @C_PRODREGRAS_VRPEFATNUTPR NUMERIC(15,6);
   DECLARE @C_PRODREGRAS_QTCALCNUTRPR NUMERIC(15,6);
   DECLARE @C_PRODREGRAS_QTBRUTAPRUNR NUMERIC(15,6);
   DECLARE @C_PRODREGRAS_CDPRODDESTRE VARCHAR(10);
   DECLARE @C_PRODREGRAS_QTPRODDESTRE NUMERIC(15,6);

   DECLARE @C_PRODREGRAS_ACRES_CDPRATO      VARCHAR(10);
   DECLARE @C_PRODREGRAS_ACRES_CDPRODUTO    VARCHAR(10);
   DECLARE @C_PRODREGRAS_ACRES_QTPRODPRAT   NUMERIC(15,6);
   DECLARE @C_PRODREGRAS_ACRES_VRPEFATCOCPR NUMERIC(15,6);
   DECLARE @C_PRODREGRAS_ACRES_VRPEFATCORPR NUMERIC(15,6);
   DECLARE @C_PRODREGRAS_ACRES_HRTEMPPREPPR VARCHAR(5);
   DECLARE @C_PRODREGRAS_ACRES_SGUNIDADE    VARCHAR(10);
   DECLARE @C_PRODREGRAS_ACRES_QTUNIDESTPR  NUMERIC(15,6);
   DECLARE @C_PRODREGRAS_ACRES_QTBRUTAPR    NUMERIC(15,6);
   DECLARE @C_PRODREGRAS_ACRES_IDPRODBASEPR VARCHAR(1);
   DECLARE @C_PRODREGRAS_ACRES_VRPEFATNUTPR NUMERIC(15,6);
   DECLARE @C_PRODREGRAS_ACRES_QTCALCNUTRPR NUMERIC(15,6);
   DECLARE @C_PRODREGRAS_ACRES_QTBRUTAPRUNR NUMERIC(15,6);
   DECLARE @C_PRODREGRAS_ACRES_CDPRODDESTRE VARCHAR(10);
   DECLARE @C_PRODREGRAS_ACRES_QTPRODDESTRE NUMERIC(15,6);

   DECLARE @C_REGRAS_PROD_ZERO_CDPRATO      VARCHAR(10);
   DECLARE @C_REGRAS_PROD_ZERO_CDPRODUTO    VARCHAR(10);
   DECLARE @C_REGRAS_PROD_ZERO_QTPRODPRAT   NUMERIC(15,6);
   DECLARE @C_REGRAS_PROD_ZERO_VRPEFATCOCPR NUMERIC(15,6);
   DECLARE @C_REGRAS_PROD_ZERO_VRPEFATCORPR NUMERIC(15,6);
   DECLARE @C_REGRAS_PROD_ZERO_HRTEMPPREPPR VARCHAR(5);
   DECLARE @C_REGRAS_PROD_ZERO_SGUNIDADE    VARCHAR(10);
   DECLARE @C_REGRAS_PROD_ZERO_QTUNIDESTPR  NUMERIC(15,6);
   DECLARE @C_REGRAS_PROD_ZERO_QTBRUTAPR    NUMERIC(15,6);
   DECLARE @C_REGRAS_PROD_ZERO_IDPRODBASEPR VARCHAR(1);
   DECLARE @C_REGRAS_PROD_ZERO_VRPEFATNUTPR NUMERIC(15,6);
   DECLARE @C_REGRAS_PROD_ZERO_QTCALCNUTRPR NUMERIC(15,6);
   DECLARE @C_REGRAS_PROD_ZERO_QTBRUTAPRUNR NUMERIC(15,6);
   DECLARE @C_REGRAS_PROD_ZERO_CDPRODDESTRE VARCHAR(10);
   DECLARE @C_REGRAS_PROD_ZERO_QTPRODDESTRE NUMERIC(15,6);

   DECLARE @C_PRODREGRAS_ACRESZERO_CDPRATO      VARCHAR(10);
   DECLARE @C_PRODREGRAS_ACRESZERO_CDPRODUTO    VARCHAR(10);
   DECLARE @C_PRODREGRAS_ACRESZERO_QTPRODPRAT   NUMERIC(15,6);
   DECLARE @C_PRODREGRAS_ACRESZERO_VRPEFATCOCPR NUMERIC(15,6);
   DECLARE @C_PRODREGRAS_ACRESZERO_VRPEFATCORPR NUMERIC(15,6);
   DECLARE @C_PRODREGRAS_ACRESZERO_HRTEMPPREPPR VARCHAR(5);
   DECLARE @C_PRODREGRAS_ACRESZERO_SGUNIDADE    VARCHAR(10);
   DECLARE @C_PRODREGRAS_ACRESZERO_QTUNIDESTPR  NUMERIC(15,6);
   DECLARE @C_PRODREGRAS_ACRESZERO_QTBRUTAPR    NUMERIC(15,6);
   DECLARE @C_PRODREGRAS_ACRESZERO_IDPRODBASEPR VARCHAR(1);
   DECLARE @C_PRODREGRAS_ACRESZERO_VRPEFATNUTPR NUMERIC(15,6);
   DECLARE @C_PRODREGRAS_ACRESZERO_QTCALCNUTRPR NUMERIC(15,6);
   DECLARE @C_PRODREGRAS_ACRESZERO_QTBRUTAPRUNR NUMERIC(15,6);
   DECLARE @C_PRODREGRAS_ACRESZERO_CDPRODDESTRE VARCHAR(10);
   DECLARE @C_PRODREGRAS_ACRESZERO_QTPRODDESTRE NUMERIC(15,6);

   DECLARE @C_UPDATEPROD_CDPRODUTO    VARCHAR(10);
   DECLARE @C_UPDATEPROD_QTPRODRECLOC FLOAT;
   DECLARE @C_UPDATEPROD_VRPEFATCOCLO FLOAT;
   DECLARE @C_UPDATEPROD_VRPEFATCORLO FLOAT;
   DECLARE @C_UPDATEPROD_HRTEMPPREPLO VARCHAR(5);
   DECLARE @C_UPDATEPROD_SGUNIDADE    VARCHAR(10);
   DECLARE @C_UPDATEPROD_QTBRUTALO    FLOAT;
   DECLARE @C_UPDATEPROD_IDPRODBASELO VARCHAR(1);
   DECLARE @C_UPDATEPROD_VRPEFATNUTLO FLOAT;
   DECLARE @C_UPDATEPROD_QTCALCNUTRLO FLOAT;
   DECLARE @C_UPDATEPROD_QTBRUTALOUNR NUMERIC(15,6);
   DECLARE @C_UPDATEPROD_CDPRODDESTRE VARCHAR(10);
   DECLARE @C_UPDATEPROD_QTPRODDESTRE NUMERIC(15,6);

   DECLARE @V_PROD_JA_EXISTE VARCHAR(10);
   DECLARE @V_S VARCHAR(1);
   DECLARE @V_A VARCHAR(1);
   DECLARE @V_P VARCHAR(1);
BEGIN
   SET @V_S = 'S';
   SET @V_A = 'A';
   SET @V_P = 'P';
   DECLARE C_PRATOSORIG CURSOR FOR
      (SELECT
          CDPRATO
       FROM
          PRATO
       WHERE
          CDFILAUXPRAT = @V_P AND
          CDPRATO BETWEEN @P_CDPRATOINI AND LEFT(@P_CDPRATOFIN + REPLICATE('z', 10), 10) AND
          CDNVPRATO = (SELECT MAX(CDNVPRATO) FROM PRATO))

   OPEN C_PRATOSORIG;
   FETCH NEXT FROM C_PRATOSORIG INTO @CUR_PRATO;

   WHILE (@@FETCH_STATUS = 0) BEGIN
      DECLARE C_FILIAISAGREG CURSOR FOR
         (SELECT
             CDLISTA AS CDFILIAL
          FROM
             LISTA
          WHERE
             NRLISTA = @P_NRLISTA)

      OPEN C_FILIAISAGREG;
      FETCH NEXT FROM C_FILIAISAGREG INTO @CUR_FILIAL;

      WHILE (@@FETCH_STATUS = 0) BEGIN
         SET @V_CONTPROD = 0;

         SELECT @V_IDQTLIQUBRUT = IDQTLIQUBRUT
         FROM   PARAMPLANEJA
         WHERE  CDFILIAL = @CUR_FILIAL;

         SELECT @V_CONTPROD = COUNT(*)
         FROM RECEFILI
         WHERE
            CDFILIAL     = @CUR_FILIAL AND
            CDPRATO      = @CUR_PRATO  AND
            CDFILAUXPRAT = @V_P;

         IF @V_CONTPROD > 0 BEGIN
            SET @V_CONTPROD = 0;
            SELECT @V_CONTPROD = COUNT(*)
            FROM
               REGRAREVRECE RR,
               RECEFILI RF,
               PRODUTO P
            WHERE
               RR.CDFILIAL     = @CUR_FILIAL  AND
               RR.IDAPLICAREG  = @V_S         AND
               RF.CDFILIAL     = RR.CDFILIAL  AND
               RF.CDFILAUXPRAT = @V_P         AND
               RF.CDPRATO      = @CUR_PRATO   AND
               RR.CDPRODORIGRE = RF.CDPRODUTO AND
               RR.QTPRODORIGRE IN (CASE @V_IDQTLIQUBRUT WHEN 'B' THEN ROUND(RF.QTPRODRECLOC, 5) ELSE ROUND(RF.QTBRUTALOUNR, 5) END, 0) AND
               RF.CDPRODUTO    = P.CDPRODUTO  AND
               ISNULL(RF.SGUNIDADE, P.SGUNIDADE) = P.SGUNIDADE;



            /*S aplica a regra se pelo menos um produto da regra coincidir com algum produto da receita LOCAL */
            IF @V_CONTPROD > 0 BEGIN
               /* OPO DE SOBREPOR */
               IF @P_TIPOIMPORT = @V_S BEGIN
                  DELETE FROM RECEFILI
                  WHERE
                     CDFILIAL     = @CUR_FILIAL AND
                     CDPRATO      = @CUR_PRATO  AND
                     CDFILAUXPRAT = @V_P        AND
                     NOT EXISTS (SELECT P.CDPRODUTO
                                   FROM  REGRAREVRECE RR, PRODUTO P
                                  WHERE
                                     RR.CDFILIAL         = RECEFILI.CDFILIAL    AND
                                     RR.IDAPLICAREG      = @V_S                 AND
                                     RR.CDPRODORIGRE     = RECEFILI.CDPRODUTO   AND
                                     RR.QTPRODORIGRE IN (CASE @V_IDQTLIQUBRUT WHEN 'B' THEN ROUND(RECEFILI.QTPRODRECLOC, 5) ELSE ROUND(RECEFILI.QTBRUTALOUNR, 5) END, 0) AND
                                     RECEFILI.CDPRODUTO  = P.CDPRODUTO          AND
                                     ISNULL(RECEFILI.SGUNIDADE, P.SGUNIDADE) = P.SGUNIDADE)
               END;

               DECLARE C_UPDATEPROD CURSOR FOR
                  SELECT
                     RF.CDPRODUTO,
                     RF.QTPRODRECLOC,
                     RF.VRPEFATCOCLO,
                     RF.VRPEFATCORLO,
                     RF.HRTEMPPREPLO,
                     RF.SGUNIDADE,
                     RF.QTBRUTALO,/*Deve possuir o mesmo valor que a Quantidade requerida */
                     RF.IDPRODBASELO,
                     RF.VRPEFATNUTLO,
                     RF.QTCALCNUTRLO,
                     RF.QTBRUTALOUNR,
                     RR.CDPRODDESTRE,
                     RR.QTPRODDESTRE

                  FROM
                     REGRAREVRECE RR LEFT JOIN PRODFILI PF ON 
                                          RR.CDFILIAL     = PF.CDFILIAL   AND
                                          RR.CDPRODDESTRE = PF.CDPRODUTO,
                     RECEFILI RF,
                     PRODUTO P,
                     PRODUTO PV

                  WHERE
                     RR.CDFILIAL                       = @CUR_FILIAL                              AND
                     RR.IDAPLICAREG                    = @V_S                                     AND
                     RF.CDFILIAL                       = RR.CDFILIAL                              AND
                     RF.CDFILAUXPRAT                   = @V_P                                     AND
                     RF.CDPRATO                        = @CUR_PRATO                               AND
                     ISNULL(PF.IDCNTRESTOQ, @V_S)      = @V_S                                     AND
                     ISNULL(PF.IDPRODATIV, @V_A)       = @V_A                                     AND
                     PV.CDPRODUTO                      = ISNULL(RR.CDPRODDESTRE, RR.CDPRODORIGRE) AND
                     PV.IDPRODATIVPR                   = @V_S                                     AND
                     RR.CDPRODORIGRE                   = RF.CDPRODUTO                             AND
                     RR.QTPRODORIGRE IN (CASE @V_IDQTLIQUBRUT WHEN 'B' THEN ROUND(RF.QTPRODRECLOC, 5) ELSE ROUND(RF.QTBRUTALOUNR, 5) END, 0) AND
                     RF.CDPRODUTO                      = P.CDPRODUTO                              AND
                     ISNULL(RF.SGUNIDADE, P.SGUNIDADE) = P.SGUNIDADE                              AND
                     NOT EXISTS (SELECT REC.CDPRODUTO
                                 FROM   RECEFILI REC
                                 WHERE  REC.CDFILIAL     = RF.CDFILIAL     AND
                                        REC.CDFILAUXPRAT = RF.CDFILAUXPRAT AND
                                        REC.CDPRATO      = RF.CDPRATO      AND
                                        REC.CDPRODUTO    = RR.CDPRODDESTRE AND
                                        RR.QTPRODDESTRE IN (CASE @V_IDQTLIQUBRUT WHEN 'B' THEN ROUND(REC.QTPRODRECLOC, 5) ELSE ROUND(REC.QTBRUTALOUNR, 5) END, 0))


               OPEN C_UPDATEPROD;
               FETCH NEXT FROM C_UPDATEPROD INTO @C_UPDATEPROD_CDPRODUTO,       @C_UPDATEPROD_QTPRODRECLOC,
                                                 @C_UPDATEPROD_VRPEFATCOCLO,    @C_UPDATEPROD_VRPEFATCORLO,
                                                 @C_UPDATEPROD_HRTEMPPREPLO,    @C_UPDATEPROD_SGUNIDADE,
                                                 @C_UPDATEPROD_QTBRUTALO,       @C_UPDATEPROD_IDPRODBASELO,
                                                 @C_UPDATEPROD_VRPEFATNUTLO,    @C_UPDATEPROD_QTCALCNUTRLO,
                                                 @C_UPDATEPROD_QTBRUTALOUNR,    @C_UPDATEPROD_CDPRODDESTRE,
                                                 @C_UPDATEPROD_QTPRODDESTRE;

               WHILE (@@FETCH_STATUS = 0) BEGIN
                  IF (@C_UPDATEPROD_CDPRODDESTRE IS NULL) BEGIN
                    DELETE FROM RECEFILI
                    WHERE
                       (CDFILIAL     = @CUR_FILIAL)   AND
                       (CDFILAUXPRAT = @V_P)          AND
                       (CDPRATO      = @CUR_PRATO)    AND
                       (CDPRODUTO    = @C_UPDATEPROD_CDPRODUTO);
                  END
                  ELSE BEGIN
                    IF @C_UPDATEPROD_QTPRODDESTRE <> 0 BEGIN
                       SET @V_QTLIQUIDA = 0;
                       SET @V_QTBRUTA   = 0;
                       SET @V_QTCALC    = 0;
                       SET @V_QTCALCNUT = 0;

                       IF (@C_UPDATEPROD_VRPEFATCOCLO IS NULL) OR (@C_UPDATEPROD_VRPEFATCOCLO = 0) BEGIN
                          SET @V_QTCALC = @C_UPDATEPROD_QTPRODDESTRE;
                       END
                       ELSE BEGIN
                          IF @V_IDQTLIQUBRUT = 'B' BEGIN
                             SET @V_QTCALC = @C_UPDATEPROD_QTPRODDESTRE * (100 / (100 + @C_UPDATEPROD_VRPEFATCOCLO));
                          END
                          ELSE BEGIN
                             SET @V_QTCALC = @C_UPDATEPROD_QTPRODDESTRE / (100 / (100 + @C_UPDATEPROD_VRPEFATCOCLO));
                          END
                       END
                       IF @V_IDQTLIQUBRUT = 'B' BEGIN
                          SET @V_QTLIQUIDA = @C_UPDATEPROD_QTPRODDESTRE;
                          IF (@C_UPDATEPROD_VRPEFATCORLO IS NULL) OR (@C_UPDATEPROD_VRPEFATCORLO = 0) BEGIN
                             SET @V_QTBRUTA = @V_QTCALC;
                          END
                          ELSE BEGIN
                             SET @V_QTBRUTA = @V_QTCALC * (100 / (100 - @C_UPDATEPROD_VRPEFATCORLO));
                          END
                       END
                       ELSE BEGIN
                          SET @V_QTBRUTA = @C_UPDATEPROD_QTPRODDESTRE;
                          IF (@C_UPDATEPROD_VRPEFATCORLO IS NULL) OR (@C_UPDATEPROD_VRPEFATCORLO = 0) BEGIN
                             SET @V_QTLIQUIDA = @V_QTCALC;
	                          END
                          ELSE BEGIN
                             SET @V_QTLIQUIDA = @V_QTCALC / (100 / (100 - @C_UPDATEPROD_VRPEFATCORLO));
                          END
                       END
                       IF (@C_UPDATEPROD_VRPEFATNUTLO IS NULL) OR (@C_UPDATEPROD_VRPEFATNUTLO = 0) BEGIN
                          SET @V_QTCALCNUT = @V_QTLIQUIDA;
                       END
                       ELSE BEGIN
                          SET @V_QTCALCNUT = (@V_QTLIQUIDA * @C_UPDATEPROD_VRPEFATNUTLO) / 100;
                       END
                       UPDATE RECEFILI
                       SET CDPRODUTO    = @C_UPDATEPROD_CDPRODDESTRE,
                           QTPRODRECLOC = @V_QTLIQUIDA,
                           VRPEFATCOCLO = @C_UPDATEPROD_VRPEFATCOCLO,
                           VRPEFATCORLO = @C_UPDATEPROD_VRPEFATCORLO,
                           SGUNIDADE    = @C_UPDATEPROD_SGUNIDADE,
                           QTUNIDESTLO  = @V_QTBRUTA,
                           QTBRUTALO    = @V_QTBRUTA,
                           IDPRODBASELO = @C_UPDATEPROD_IDPRODBASELO,
                           DTULTATURECF = GETDATE(),
                           VRPEFATNUTLO = @C_UPDATEPROD_VRPEFATNUTLO,
                           QTCALCNUTRLO = @V_QTCALCNUT,
                           QTBRUTALOUNR = @V_QTBRUTA
                       WHERE
                           (CDFILIAL     = @CUR_FILIAL)              AND
                           (CDFILAUXPRAT = @V_P)                     AND
                           (CDPRATO      = @CUR_PRATO)               AND
                           (CDPRODUTO    = @C_UPDATEPROD_CDPRODUTO)
                    END
                    ELSE BEGIN
                       UPDATE RECEFILI
                       SET CDPRODUTO = @C_UPDATEPROD_CDPRODDESTRE,
                           SGUNIDADE = @C_UPDATEPROD_SGUNIDADE
                       WHERE
                           (CDFILIAL     = @CUR_FILIAL) AND
                           (CDFILAUXPRAT = @V_P)        AND
                           (CDPRATO      = @CUR_PRATO)  AND
                           (CDPRODUTO    = @C_UPDATEPROD_CDPRODUTO)
                    END
                  END
                  FETCH NEXT FROM C_UPDATEPROD INTO @C_UPDATEPROD_CDPRODUTO,       @C_UPDATEPROD_QTPRODRECLOC,
                                                    @C_UPDATEPROD_VRPEFATCOCLO,    @C_UPDATEPROD_VRPEFATCORLO,
                                                    @C_UPDATEPROD_HRTEMPPREPLO,    @C_UPDATEPROD_SGUNIDADE,
                                                    @C_UPDATEPROD_QTBRUTALO,       @C_UPDATEPROD_IDPRODBASELO,
                                                    @C_UPDATEPROD_VRPEFATNUTLO,    @C_UPDATEPROD_QTCALCNUTRLO,
                                                    @C_UPDATEPROD_QTBRUTALOUNR,    @C_UPDATEPROD_CDPRODDESTRE,
                                                    @C_UPDATEPROD_QTPRODDESTRE;
               END
             CLOSE C_UPDATEPROD;
             DEALLOCATE C_UPDATEPROD;

            END    /* REGRA APLICADA RECEITA LOCAL */
         END
         /**/
         ELSE BEGIN   /* APLICAR NA RECEITA PADRAO PARA LOCAL*/
            SELECT @V_CONTPROD = COUNT(*)
              FROM
                 REGRAREVRECE RR,
                 RECEPADR RP,
                 PRODUTO P
              WHERE
                 RR.CDFILIAL     = @CUR_FILIAL  AND
                 RR.IDAPLICAREG  = @V_S         AND
                 RP.CDFILAUXPRAT = @V_P         AND
                 RP.CDPRATO      = @CUR_PRATO   AND
                 RR.CDPRODORIGRE = RP.CDPRODUTO AND
                 RR.QTPRODORIGRE IN (CASE @V_IDQTLIQUBRUT WHEN 'B' THEN ROUND(RP.QTPRODPRAT, 5) ELSE ROUND(RP.QTBRUTAPRUNR, 5) END, 0) AND
                 RP.CDPRODUTO    = P.CDPRODUTO  AND
                 ISNULL(RP.SGUNIDADE, P.SGUNIDADE) = P.SGUNIDADE;

            /*S aplica a regra se pelo menos um produto da regra coincidir com algum produto da receita padro*/
            IF @V_CONTPROD > 0 BEGIN
               /* OPO DE SOBREPOR */
               IF @P_TIPOIMPORT = @V_S BEGIN
                  DELETE FROM RECEFILI
                   WHERE
                     CDFILIAL     = @CUR_FILIAL AND
                     CDPRATO      = @CUR_PRATO  AND
                     CDFILAUXPRAT = @V_P;

                  /*INSERE NA RECEFILI TODOS OS PRODUTOS DA RECEPADR QUE NO EXISTAM NA REGRAS*/
                  INSERT INTO RECEFILI
                     (CDFILAUXPRAT,
                      CDPRATO,
                      CDFILIAL,
                      CDPRODUTO,
                      QTPRODRECLOC,
                      VRPEFATCOCLO,
                      VRPEFATCORLO,
                      HRTEMPPREPLO,
                      SGUNIDADE,
                      QTUNIDESTLO,
                      QTBRUTALO,
                      IDPRODBASELO,
                      DTULTATURECF,
                      VRPEFATNUTLO,
                      QTCALCNUTRLO,
                      QTBRUTALOUNR)
                  (SELECT
                      @V_P,
                      R.CDPRATO,
                      @CUR_FILIAL,
                      R.CDPRODUTO,
                      R.QTPRODPRAT,
                      R.VRPEFATCOCPR,
                      R.VRPEFATCORPR,
                      R.HRTEMPPREPPR,
                      R.SGUNIDADE,
                      R.QTBRUTAPR,/*Deve ser igual a quantidade requerida*/
                      R.QTBRUTAPR,
                      R.IDPRODBASEPR,
                      GETDATE(),
                      R.VRPEFATNUTPR,
                      R.QTCALCNUTRPR,
                      R.QTBRUTAPRUNR
                   FROM
                      PRODUTO P,
                      RECEPADR R LEFT JOIN PRODFILI PF ON
                                      R.CDPRODUTO = PF.CDPRODUTO AND
                                      @CUR_FILIAL = PF.CDFILIAL
                   WHERE
                      R.CDPRATO                    = @CUR_PRATO      AND
                      R.CDFILAUXPRAT               = @V_P            AND
                      R.CDPRODUTO                  = P.CDPRODUTO     AND
                      ISNULL(PF.IDCNTRESTOQ, @V_S) = @V_S            AND
                      ISNULL(PF.IDPRODATIV, @V_A)  = @V_A            AND
                      P.IDPRODATIVPR               = @V_S            AND
                      NOT EXISTS (SELECT RE.CDPRODORIGRE
                                  FROM   REGRAREVRECE RE,
                                         PRODUTO PT
                                  WHERE  RE.CDFILIAL                       = @CUR_FILIAL  AND
                                         RE.IDAPLICAREG                    = @V_S         AND
                                         RE.CDPRODORIGRE                   = R.CDPRODUTO  AND
                                         RE.QTPRODORIGRE IN (CASE @V_IDQTLIQUBRUT WHEN 'B' THEN ROUND(R.QTPRODPRAT, 5) ELSE ROUND(R.QTBRUTAPRUNR, 5) END, 0) AND
                                         RE.CDPRODORIGRE                   = PT.CDPRODUTO AND
                                         ISNULL(R.SGUNIDADE, PT.SGUNIDADE) = PT.SGUNIDADE));

                    /*RETORNA OS PRODUTOS QUE EXISTAM NA RECEPADR, EXISTAM NA REGRAS E QUE O PRODUTO DE
                    DESTINO NO EXISTA NA RECEFILI*/
                  DECLARE C_PRODREGRAS CURSOR FOR
                     SELECT RC.CDPRATO,
                            RC.CDPRODUTO,
                            RC.QTPRODPRAT,
                            RC.VRPEFATCOCPR,
                            RC.VRPEFATCORPR,
                            RC.HRTEMPPREPPR,
                            RC.SGUNIDADE,
                            RC.QTUNIDESTPR,
                            RC.QTBRUTAPR,
                            RC.IDPRODBASEPR,
                            RC.VRPEFATNUTPR,
                            RC.QTCALCNUTRPR,
                            RC.QTBRUTAPRUNR,
                            R.CDPRODDESTRE,
                            R.QTPRODDESTRE
                     FROM PRODUTO P,
                          RECEPADR RC LEFT JOIN PRODFILI PF ON
                                                @CUR_FILIAL  = PF.CDFILIAL AND
                                                RC.CDPRODUTO = PF.CDPRODUTO,
                          REGRAREVRECE R
                     WHERE
                        RC.CDPRODUTO                      = P.CDPRODUTO       AND
                        ISNULL(PF.IDCNTRESTOQ, @V_S)      = @V_S              AND
                        ISNULL(PF.IDPRODATIV, @V_A)       = @V_A              AND
                        P.IDPRODATIVPR                    = @V_S              AND
                        RC.CDFILAUXPRAT                   = @V_P              AND
                        RC.CDPRATO                        = @CUR_PRATO        AND
                        R.CDFILIAL                        = @CUR_FILIAL       AND
                        R.IDAPLICAREG                     = @V_S              AND
                        R.CDPRODDESTRE IS NOT NULL                            AND
                        R.CDPRODORIGRE                    = RC.CDPRODUTO      AND
                        R.QTPRODORIGRE = CASE @V_IDQTLIQUBRUT WHEN 'B' THEN ROUND(RC.QTPRODPRAT, 5) ELSE ROUND(RC.QTBRUTAPRUNR, 5) END AND
                        ISNULL(RC.SGUNIDADE, P.SGUNIDADE) = P.SGUNIDADE AND
                        NOT EXISTS (SELECT RF.CDPRODUTO
                                    FROM   RECEFILI RF
                                    WHERE  RF.CDFILIAL     = @CUR_FILIAL AND
                                           RF.CDFILAUXPRAT = @V_P        AND
                                           RF.CDPRATO      = @CUR_PRATO  AND
                                           RF.CDPRODUTO    = R.CDPRODDESTRE)
                     ORDER BY P.CDARVPROD

                  OPEN C_PRODREGRAS;
                  FETCH NEXT FROM C_PRODREGRAS INTO @C_PRODREGRAS_CDPRATO,      @C_PRODREGRAS_CDPRODUTO,
                                                    @C_PRODREGRAS_QTPRODPRAT,   @C_PRODREGRAS_VRPEFATCOCPR,
                                                    @C_PRODREGRAS_VRPEFATCORPR, @C_PRODREGRAS_HRTEMPPREPPR,
                                                    @C_PRODREGRAS_SGUNIDADE,    @C_PRODREGRAS_QTUNIDESTPR,
                                                    @C_PRODREGRAS_QTBRUTAPR,    @C_PRODREGRAS_IDPRODBASEPR,
                                                    @C_PRODREGRAS_VRPEFATNUTPR, @C_PRODREGRAS_QTCALCNUTRPR,
                                                    @C_PRODREGRAS_QTBRUTAPRUNR, @C_PRODREGRAS_CDPRODDESTRE,
                                                    @C_PRODREGRAS_QTPRODDESTRE;

                  WHILE (@@FETCH_STATUS = 0) BEGIN
                     SELECT @V_PROD_JA_EXISTE = MAX(CDPRODUTO)
                     FROM   RECEFILI
                     WHERE  CDFILIAL     = @CUR_FILIAL AND
                            CDPRATO      = @CUR_PRATO  AND
                            CDFILAUXPRAT = @V_P        AND
                            CDPRODUTO    = @C_PRODREGRAS_CDPRODDESTRE;
                     IF @V_PROD_JA_EXISTE IS NULL BEGIN
                        SET @V_QTLIQUIDA = 0;
                        SET @V_QTBRUTA   = 0;
                        SET @V_QTCALC    = 0;
                        SET @V_QTCALCNUT = 0;

                        IF (@C_PRODREGRAS_VRPEFATCOCPR IS NULL) OR (@C_PRODREGRAS_VRPEFATCOCPR = 0) BEGIN
                           SET @V_QTCALC = @C_PRODREGRAS_QTPRODDESTRE;
                        END ELSE BEGIN
                           IF @V_IDQTLIQUBRUT = 'B' BEGIN
                              SET @V_QTCALC = @C_PRODREGRAS_QTPRODDESTRE * (100 / (100 + @C_PRODREGRAS_VRPEFATCOCPR));
                           END ELSE BEGIN
                              SET @V_QTCALC = @C_PRODREGRAS_QTPRODDESTRE / (100 / (100 + @C_PRODREGRAS_VRPEFATCOCPR));
                           END;
                        END;

                        IF @V_IDQTLIQUBRUT = 'B' BEGIN
                           SET @V_QTLIQUIDA = @C_PRODREGRAS_QTPRODDESTRE;
                           IF (@C_PRODREGRAS_VRPEFATCORPR IS NULL) OR (@C_PRODREGRAS_VRPEFATCORPR = 0) BEGIN
                              SET @V_QTBRUTA = @V_QTCALC;
                           END ELSE BEGIN
                              SET @V_QTBRUTA = @V_QTCALC * (100 / (100 - @C_PRODREGRAS_VRPEFATCORPR));
                           END;
                        END ELSE BEGIN
                           SET @V_QTBRUTA = @C_PRODREGRAS_QTPRODDESTRE;
                           IF (@C_PRODREGRAS_VRPEFATCORPR IS NULL) OR (@C_PRODREGRAS_VRPEFATCORPR = 0) BEGIN
                              SET @V_QTLIQUIDA = @V_QTCALC;
                           END ELSE BEGIN
                              SET @V_QTLIQUIDA = @V_QTCALC / (100 / (100 - @C_PRODREGRAS_VRPEFATCORPR));
                           END;
                        END;

                        IF (@C_PRODREGRAS_VRPEFATNUTPR IS NULL) OR (@C_PRODREGRAS_VRPEFATNUTPR = 0) BEGIN
                           SET @V_QTCALCNUT = @V_QTLIQUIDA;
                        END ELSE BEGIN
                           SET @V_QTCALCNUT = (@V_QTLIQUIDA * @C_PRODREGRAS_VRPEFATNUTPR) / 100;
                        END;

                        INSERT INTO RECEFILI
                           (CDFILAUXPRAT,
                            CDPRATO,
                            CDFILIAL,
                            CDPRODUTO,
                            QTPRODRECLOC, /*Quantidade lquida*/
                            VRPEFATCOCLO,
                            VRPEFATCORLO,
                            HRTEMPPREPLO,
                            SGUNIDADE,
                            QTUNIDESTLO,
                            QTBRUTALO,    /*Quantidade requerida*/
                            IDPRODBASELO,
                            DTULTATURECF,
                            VRPEFATNUTLO,
                            QTCALCNUTRLO,
                            QTBRUTALOUNR) /*Quantidade bruta*/
                        VALUES
                           (@V_P,
                            @C_PRODREGRAS_CDPRATO,
                            @CUR_FILIAL,
                            @C_PRODREGRAS_CDPRODDESTRE,
                            @V_QTLIQUIDA,
                            @C_PRODREGRAS_VRPEFATCOCPR,
                            @C_PRODREGRAS_VRPEFATCORPR,
                            @C_PRODREGRAS_HRTEMPPREPPR,
                            @C_PRODREGRAS_SGUNIDADE,
                            @V_QTBRUTA,/*Deve ser igual a quantidade requerida*/
                            @V_QTBRUTA,
                            @C_PRODREGRAS_IDPRODBASEPR,
                            GETDATE(),
                            @C_PRODREGRAS_VRPEFATNUTPR,
                            @V_QTCALCNUT,
                            @V_QTBRUTA);
                     END;

                     FETCH NEXT FROM C_PRODREGRAS INTO @C_PRODREGRAS_CDPRATO,      @C_PRODREGRAS_CDPRODUTO,
                                                       @C_PRODREGRAS_QTPRODPRAT,   @C_PRODREGRAS_VRPEFATCOCPR,
                                                       @C_PRODREGRAS_VRPEFATCORPR, @C_PRODREGRAS_HRTEMPPREPPR,
                                                       @C_PRODREGRAS_SGUNIDADE,    @C_PRODREGRAS_QTUNIDESTPR,
                                                       @C_PRODREGRAS_QTBRUTAPR,    @C_PRODREGRAS_IDPRODBASEPR,
                                                       @C_PRODREGRAS_VRPEFATNUTPR, @C_PRODREGRAS_QTCALCNUTRPR,
                                                       @C_PRODREGRAS_QTBRUTAPRUNR, @C_PRODREGRAS_CDPRODDESTRE,
                                                       @C_PRODREGRAS_QTPRODDESTRE;
                  END;

                  CLOSE C_PRODREGRAS;
                  DEALLOCATE C_PRODREGRAS;

                  /*RETORNA TODOS OS PRODUTOS QUE ESTO ZERADOS NA REGRA, QUE EXISTAM NA RECEPADR E QUE J
                    NO TENHA SIDO APLICADA REGRA AO PRODUTO*/
                  DECLARE C_REGRAS_PROD_ZERO CURSOR FOR
                     (SELECT
                        RC.CDPRATO,
                        RC.CDPRODUTO,
                        RC.QTPRODPRAT,
                        RC.VRPEFATCOCPR,
                        RC.VRPEFATCORPR,
                        RC.HRTEMPPREPPR,
                        RC.SGUNIDADE,
                        RC.QTUNIDESTPR,
                        RC.QTBRUTAPR,
                        RC.IDPRODBASEPR,
                        RC.VRPEFATNUTPR,
                        RC.QTCALCNUTRPR,
                        RC.QTBRUTAPRUNR,
                        R.CDPRODDESTRE,
                        R.QTPRODDESTRE
                     FROM
                        PRODUTO P,
                        RECEPADR RC LEFT JOIN PRODFILI PF ON
                                         @CUR_FILIAL  = PF.CDFILIAL AND
                                         RC.CDPRODUTO = PF.CDPRODUTO,
                        REGRAREVRECE R
                     WHERE
                        RC.CDPRODUTO                      = P.CDPRODUTO    AND
                        ISNULL(PF.IDCNTRESTOQ, @V_S)      = @V_S           AND
                        ISNULL(PF.IDPRODATIV, @V_A)       = @V_A           AND
                        P.IDPRODATIVPR                    = @V_S           AND
                        RC.CDFILAUXPRAT                   = @V_P           AND
                        RC.CDPRATO                        = @CUR_PRATO     AND
                        R.CDFILIAL                        = @CUR_FILIAL    AND
                        R.IDAPLICAREG                     = @V_S           AND
                        R.CDPRODDESTRE IS NOT NULL                         AND
                        R.CDPRODORIGRE                    = RC.CDPRODUTO   AND
                        R.QTPRODORIGRE                    = 0              AND
                        ISNULL(RC.SGUNIDADE, P.SGUNIDADE) = P.SGUNIDADE    AND
                        NOT EXISTS (SELECT
                                       R.CDPRODORIGRE
                                    FROM
                                       PRODUTO P,
                                       RECEPADR RC LEFT JOIN PRODFILI PF ON
                                                        @CUR_FILIAL  = PF.CDFILIAL AND
                                                        RC.CDPRODUTO = PF.CDPRODUTO,
                                       REGRAREVRECE R
                                    WHERE
                                       RC.CDPRODUTO                      = P.CDPRODUTO        AND
                                       ISNULL(PF.IDCNTRESTOQ, @V_S)      = @V_S               AND
                                       ISNULL(PF.IDPRODATIV, @V_A)       = @V_A               AND
                                       P.IDPRODATIVPR                    = @V_S               AND
                                       RC.CDFILAUXPRAT                   = @V_P               AND
                                       RC.CDPRATO                        = @CUR_PRATO         AND
                                       R.CDFILIAL                        = @CUR_FILIAL        AND
                                       R.IDAPLICAREG                     = @V_S               AND
                                       R.CDPRODORIGRE                    = RC.CDPRODUTO       AND
                                       R.QTPRODORIGRE  = CASE @V_IDQTLIQUBRUT WHEN 'B' THEN ROUND(RC.QTPRODPRAT, 5) ELSE ROUND(RC.QTBRUTAPRUNR, 5) END AND
                                       ISNULL(RC.SGUNIDADE, P.SGUNIDADE) = P.SGUNIDADE        AND
                                       R.CDPRODORIGRE                    = RC.CDPRODUTO)      AND
                        NOT EXISTS (SELECT RF.CDPRODUTO
                                    FROM   RECEFILI RF
                                    WHERE  RF.CDFILIAL     = @CUR_FILIAL AND
                                           RF.CDFILAUXPRAT = @V_P        AND
                                           RF.CDPRATO      = @CUR_PRATO  AND
                                           RF.CDPRODUTO    = R.CDPRODDESTRE))

                  OPEN C_REGRAS_PROD_ZERO;
                  FETCH NEXT FROM C_REGRAS_PROD_ZERO INTO @C_REGRAS_PROD_ZERO_CDPRATO,      @C_REGRAS_PROD_ZERO_CDPRODUTO,
                                                          @C_REGRAS_PROD_ZERO_QTPRODPRAT,   @C_REGRAS_PROD_ZERO_VRPEFATCOCPR,
                                                          @C_REGRAS_PROD_ZERO_VRPEFATCORPR, @C_REGRAS_PROD_ZERO_HRTEMPPREPPR,
                                                          @C_REGRAS_PROD_ZERO_SGUNIDADE,    @C_REGRAS_PROD_ZERO_QTUNIDESTPR,
                                                          @C_REGRAS_PROD_ZERO_QTBRUTAPR,    @C_REGRAS_PROD_ZERO_IDPRODBASEPR,
                                                          @C_REGRAS_PROD_ZERO_VRPEFATNUTPR, @C_REGRAS_PROD_ZERO_QTCALCNUTRPR,
                                                          @C_REGRAS_PROD_ZERO_QTBRUTAPRUNR, @C_REGRAS_PROD_ZERO_CDPRODDESTRE,
                                                          @C_REGRAS_PROD_ZERO_QTPRODDESTRE;

                  WHILE (@@FETCH_STATUS = 0) BEGIN
                     SELECT @V_PROD_JA_EXISTE = MAX(CDPRODUTO)
                     FROM   RECEFILI
                     WHERE  CDFILIAL     = @CUR_FILIAL AND
                            CDPRATO      = @CUR_PRATO  AND
                            CDFILAUXPRAT = @V_P        AND
                            CDPRODUTO    = @C_REGRAS_PROD_ZERO_CDPRODDESTRE;
                     IF @V_PROD_JA_EXISTE IS NULL BEGIN
                        IF @C_REGRAS_PROD_ZERO_QTPRODDESTRE <> 0 BEGIN
                           SET @V_QTLIQUIDA = 0;
                           SET @V_QTBRUTA   = 0;
                           SET @V_QTCALC    = 0;
                           SET @V_QTCALCNUT = 0;

                           IF (@C_REGRAS_PROD_ZERO_VRPEFATCOCPR IS NULL) OR (@C_REGRAS_PROD_ZERO_VRPEFATCOCPR = 0) BEGIN
                              SET @V_QTCALC = @C_REGRAS_PROD_ZERO_QTPRODDESTRE;
                           END ELSE BEGIN
                              IF @V_IDQTLIQUBRUT = 'B' BEGIN
                                 SET @V_QTCALC = @C_REGRAS_PROD_ZERO_QTPRODDESTRE * (100 / (100 + @C_REGRAS_PROD_ZERO_VRPEFATCOCPR));
                              END ELSE BEGIN
                                 SET @V_QTCALC = @C_REGRAS_PROD_ZERO_QTPRODDESTRE / (100 / (100 + @C_REGRAS_PROD_ZERO_VRPEFATCOCPR));
                              END;
                           END;

                           IF @V_IDQTLIQUBRUT = 'B' BEGIN
                              SET @V_QTLIQUIDA = @C_REGRAS_PROD_ZERO_QTPRODDESTRE;
                              IF (@C_REGRAS_PROD_ZERO_VRPEFATCORPR IS NULL) OR (@C_REGRAS_PROD_ZERO_VRPEFATCORPR = 0) BEGIN
                                 SET @V_QTBRUTA = @V_QTCALC;
                              END ELSE BEGIN
                                 SET @V_QTBRUTA = @V_QTCALC * (100 / (100 - @C_REGRAS_PROD_ZERO_VRPEFATCORPR));
                              END;
                           END ELSE BEGIN
                              SET @V_QTBRUTA = @C_REGRAS_PROD_ZERO_QTPRODDESTRE;
                              IF (@C_REGRAS_PROD_ZERO_VRPEFATCORPR IS NULL) OR (@C_REGRAS_PROD_ZERO_VRPEFATCORPR = 0) BEGIN
                                 SET @V_QTLIQUIDA = @V_QTCALC;
                              END ELSE BEGIN
                                 SET @V_QTLIQUIDA = @V_QTCALC / (100 / (100 - @C_REGRAS_PROD_ZERO_VRPEFATCORPR));
                              END;
                           END;

                           IF (@C_REGRAS_PROD_ZERO_VRPEFATNUTPR IS NULL) OR (@C_REGRAS_PROD_ZERO_VRPEFATNUTPR = 0) BEGIN
                              SET @V_QTCALCNUT = @V_QTLIQUIDA;
                           END ELSE BEGIN
                              SET @V_QTCALCNUT = (@V_QTLIQUIDA * @C_REGRAS_PROD_ZERO_VRPEFATNUTPR) / 100;
                           END;
                        END ELSE BEGIN
                           SET @V_QTLIQUIDA = @C_REGRAS_PROD_ZERO_QTPRODPRAT;
                           SET @V_QTBRUTA   = @C_REGRAS_PROD_ZERO_QTBRUTAPR;
                           SET @V_QTCALCNUT = @C_REGRAS_PROD_ZERO_QTCALCNUTRPR;
                        END;

                        INSERT INTO RECEFILI
                           (CDFILAUXPRAT,
                            CDPRATO,
                            CDFILIAL,
                            CDPRODUTO,
                            QTPRODRECLOC, /*Quantidade lquida*/
                            VRPEFATCOCLO,
                            VRPEFATCORLO,
                            HRTEMPPREPLO,
                            SGUNIDADE,
                            QTUNIDESTLO,
                            QTBRUTALO,    /*Quantidade requerida*/
                            IDPRODBASELO,
                            DTULTATURECF,
                            VRPEFATNUTLO,
                            QTCALCNUTRLO,
                            QTBRUTALOUNR) /*Quantidade bruta*/
                        VALUES
                           (@V_P,
                            @C_REGRAS_PROD_ZERO_CDPRATO,
                            @CUR_FILIAL,
                            @C_REGRAS_PROD_ZERO_CDPRODDESTRE,
                            @V_QTLIQUIDA,
                            @C_REGRAS_PROD_ZERO_VRPEFATCOCPR,
                            @C_REGRAS_PROD_ZERO_VRPEFATCORPR,
                            @C_REGRAS_PROD_ZERO_HRTEMPPREPPR,
                            @C_REGRAS_PROD_ZERO_SGUNIDADE,
                            @V_QTBRUTA,/*Deve ser igual a quantidade requerida*/
                            @V_QTBRUTA,
                            @C_REGRAS_PROD_ZERO_IDPRODBASEPR,
                            GETDATE(),
                            @C_REGRAS_PROD_ZERO_VRPEFATNUTPR,
                            @V_QTCALCNUT,
                            @V_QTBRUTA);
                     END;
                     FETCH NEXT FROM C_REGRAS_PROD_ZERO INTO @C_REGRAS_PROD_ZERO_CDPRATO,      @C_REGRAS_PROD_ZERO_CDPRODUTO,
                                                             @C_REGRAS_PROD_ZERO_QTPRODPRAT,   @C_REGRAS_PROD_ZERO_VRPEFATCOCPR,
                                                             @C_REGRAS_PROD_ZERO_VRPEFATCORPR, @C_REGRAS_PROD_ZERO_HRTEMPPREPPR,
                                                             @C_REGRAS_PROD_ZERO_SGUNIDADE,    @C_REGRAS_PROD_ZERO_QTUNIDESTPR,
                                                             @C_REGRAS_PROD_ZERO_QTBRUTAPR,    @C_REGRAS_PROD_ZERO_IDPRODBASEPR,
                                                             @C_REGRAS_PROD_ZERO_VRPEFATNUTPR, @C_REGRAS_PROD_ZERO_QTCALCNUTRPR,
                                                             @C_REGRAS_PROD_ZERO_QTBRUTAPRUNR, @C_REGRAS_PROD_ZERO_CDPRODDESTRE,
                                                             @C_REGRAS_PROD_ZERO_QTPRODDESTRE;
                  END;

                  CLOSE C_REGRAS_PROD_ZERO;
                  DEALLOCATE C_REGRAS_PROD_ZERO;

               END ELSE BEGIN

                  /* OPO DE ACRESCENTAR ****************************************************************
                     INSERE OS PRODUTOS QUE EXISTAM NA RECEPADR, NO EXISTAM NA RECEFILI E QUE NO EXISTAM
                     NA REGRAS*/
                  INSERT INTO RECEFILI
                     (CDFILAUXPRAT,
                      CDPRATO,
                      CDFILIAL,
                      CDPRODUTO,
                      QTPRODRECLOC,
                      VRPEFATCOCLO,
                      VRPEFATCORLO,
                      HRTEMPPREPLO,
                      SGUNIDADE,
                      QTUNIDESTLO,
                      QTBRUTALO,
                      IDPRODBASELO,
                      DTULTATURECF,
                      VRPEFATNUTLO,
                      QTCALCNUTRLO,
                      QTBRUTALOUNR)
                  (SELECT
                      @V_P,
                      R.CDPRATO,
                      @CUR_FILIAL,
                      R.CDPRODUTO,
                      R.QTPRODPRAT,
                      R.VRPEFATCOCPR,
                      R.VRPEFATCORPR,
                      R.HRTEMPPREPPR,
                      R.SGUNIDADE,
                      R.QTBRUTAPR,/*Deve ser igual a quantidade requerida*/
                      R.QTBRUTAPR,
                      R.IDPRODBASEPR,
                      GETDATE(),
                      R.VRPEFATNUTPR,
                      R.QTCALCNUTRPR,
                      R.QTBRUTAPRUNR
                   FROM
                      PRODUTO P,
                      RECEPADR R LEFT JOIN PRODFILI PF ON
                                      @CUR_FILIAL = PF.CDFILIAL AND
                                      R.CDPRODUTO = PF.CDPRODUTO
                   WHERE
                      R.CDPRATO                    = @CUR_PRATO     AND
                      R.CDFILAUXPRAT               = @V_P          AND
                      R.CDPRODUTO                  = P.CDPRODUTO   AND
                      ISNULL(PF.IDCNTRESTOQ, @V_S) = @V_S          AND
                      ISNULL(PF.IDPRODATIV, @V_A)  = @V_A          AND
                      P.IDPRODATIVPR               = @V_S          AND
                      NOT EXISTS (SELECT RF.CDPRODUTO
                                  FROM   RECEFILI RF
                                  WHERE  RF.CDFILIAL     = @CUR_FILIAL  AND
                                         RF.CDPRATO      = @CUR_PRATO   AND
                                         RF.CDFILAUXPRAT = @V_P         AND
                                         RF.CDPRODUTO    = R.CDPRODUTO) AND
                      NOT EXISTS (SELECT RE.CDPRODORIGRE
                                  FROM   REGRAREVRECE RE,
                                         PRODUTO P
                                  WHERE  RE.CDFILIAL     = @CUR_FILIAL  AND
                                         RE.IDAPLICAREG  = @V_S         AND
                                         RE.CDPRODORIGRE = R.CDPRODUTO  AND
                                         RE.QTPRODORIGRE IN (CASE @V_IDQTLIQUBRUT WHEN 'B' THEN ROUND(R.QTPRODPRAT, 5) ELSE ROUND(R.QTBRUTAPRUNR, 5) END, 0) AND
                                         RE.CDPRODORIGRE = P.CDPRODUTO  AND
                                         ISNULL(R.SGUNIDADE, P.SGUNIDADE) = P.SGUNIDADE));

                  /*RETORNA OS PRODUTOS QUE EXISTAM NA RECEPADR, EXISTAM NA REGRAS E QUE O PRODUTO DE
                    ORIGEM E DESTINO NO EXISTA NA RECEFILI*/
                  DECLARE C_PRODREGRAS_ACRES CURSOR FOR
                     SELECT
                        RC.CDPRATO,
                        RC.CDPRODUTO,
                        RC.QTPRODPRAT,
                        RC.VRPEFATCOCPR,
                        RC.VRPEFATCORPR,
                        RC.HRTEMPPREPPR,
                        RC.SGUNIDADE,
                        RC.QTUNIDESTPR,
                        RC.QTBRUTAPR,
                        RC.IDPRODBASEPR,
                        RC.VRPEFATNUTPR,
                        RC.QTCALCNUTRPR,
                        RC.QTBRUTAPRUNR,
                        R.CDPRODDESTRE,
                        R.QTPRODDESTRE
                     FROM
                        PRODUTO P,
                        RECEPADR RC LEFT JOIN PRODFILI PF ON
                                         @CUR_FILIAL  = PF.CDFILIAL AND
                                         RC.CDPRODUTO = PF.CDPRODUTO,
                        REGRAREVRECE R
                     WHERE
                        RC.CDPRODUTO                 = P.CDPRODUTO       AND
                        ISNULL(PF.IDCNTRESTOQ, @V_S) = @V_S              AND
                        ISNULL(PF.IDPRODATIV, @V_A)  = @V_A              AND
                        P.IDPRODATIVPR               = @V_S              AND
                        RC.CDFILAUXPRAT              = @V_P              AND
                        RC.CDPRATO                   = @CUR_PRATO        AND
                        R.CDFILIAL                   = @CUR_FILIAL       AND
                        R.IDAPLICAREG                = @V_S              AND
                        R.CDPRODDESTRE IS NOT NULL                       AND
                        R.CDPRODORIGRE  = RC.CDPRODUTO                   AND
                        R.QTPRODORIGRE = CASE @V_IDQTLIQUBRUT WHEN 'B' THEN ROUND(RC.QTPRODPRAT, 5) ELSE ROUND(RC.QTBRUTAPRUNR, 5) END AND
                        ISNULL(RC.SGUNIDADE, P.SGUNIDADE) = P.SGUNIDADE AND
                        NOT EXISTS (SELECT RF.CDPRODUTO
                                    FROM   RECEFILI RF
                                    WHERE  RF.CDFILIAL     = @CUR_FILIAL     AND
                                           RF.CDFILAUXPRAT = @V_P            AND
                                           RF.CDPRATO      = @CUR_PRATO      AND
                                           RF.CDPRODUTO    = R.CDPRODORIGRE) AND
                        NOT EXISTS (SELECT RF.CDPRODUTO
                                    FROM   RECEFILI RF
                                    WHERE  RF.CDFILIAL     = @CUR_FILIAL     AND
                                           RF.CDFILAUXPRAT = @V_P            AND
                                           RF.CDPRATO      = @CUR_PRATO      AND
                                           RF.CDPRODUTO    = R.CDPRODDESTRE)
                     ORDER BY P.CDARVPROD
                     /*SE EXISTIREM MAIS DE UM PRODUTO NA REGRA COM O MESMO PRODUTO DE DESTINO, ENTO SER APLICADO A
                       REGRA NO PRODUTO COM MENOR CDIGO DE RVORE
                       OBS.: ISSO FOI FEITO PARA EVITAR ERRO DE PK DUPLICADA NA RECEFILI*/
                  OPEN C_PRODREGRAS_ACRES;
                  FETCH NEXT FROM C_PRODREGRAS_ACRES INTO @C_PRODREGRAS_ACRES_CDPRATO,      @C_PRODREGRAS_ACRES_CDPRODUTO,
                                                          @C_PRODREGRAS_ACRES_QTPRODPRAT,   @C_PRODREGRAS_ACRES_VRPEFATCOCPR,
                                                          @C_PRODREGRAS_ACRES_VRPEFATCORPR, @C_PRODREGRAS_ACRES_HRTEMPPREPPR,
                                                          @C_PRODREGRAS_ACRES_SGUNIDADE,    @C_PRODREGRAS_ACRES_QTUNIDESTPR,
                                                          @C_PRODREGRAS_ACRES_QTBRUTAPR,    @C_PRODREGRAS_ACRES_IDPRODBASEPR,
                                                          @C_PRODREGRAS_ACRES_VRPEFATNUTPR, @C_PRODREGRAS_ACRES_QTCALCNUTRPR,
                                                          @C_PRODREGRAS_ACRES_QTBRUTAPRUNR, @C_PRODREGRAS_ACRES_CDPRODDESTRE,
                                                          @C_PRODREGRAS_ACRES_QTPRODDESTRE;


                  WHILE (@@FETCH_STATUS = 0) BEGIN
                     SELECT @V_PROD_JA_EXISTE = MAX(CDPRODUTO)
                     FROM   RECEFILI
                     WHERE  CDFILIAL     = @CUR_FILIAL AND
                            CDPRATO      = @CUR_PRATO  AND
                            CDFILAUXPRAT = @V_P        AND
                            CDPRODUTO    = @C_PRODREGRAS_ACRES_CDPRODDESTRE;
                     /*SE GERAR EXCEO, ENTO O PRODUTO NO EXISTE NA RECEFILI E PODE SER INSERIDO*/
                     IF @V_PROD_JA_EXISTE IS NULL BEGIN
                        SET @V_QTLIQUIDA = 0;
                        SET @V_QTBRUTA   = 0;
                        SET @V_QTCALC    = 0;
                        SET @V_QTCALCNUT = 0;

                        IF (@C_PRODREGRAS_ACRES_VRPEFATCOCPR IS NULL) OR (@C_PRODREGRAS_ACRES_VRPEFATCOCPR = 0) BEGIN
                           SET @V_QTCALC = @C_PRODREGRAS_ACRES_QTPRODDESTRE;
                        END ELSE BEGIN
                           IF @V_IDQTLIQUBRUT = 'B' BEGIN
                              SET @V_QTCALC = @C_PRODREGRAS_ACRES_QTPRODDESTRE * (100 / (100 + @C_PRODREGRAS_ACRES_VRPEFATCOCPR));
                           END ELSE BEGIN
                              SET @V_QTCALC = @C_PRODREGRAS_ACRES_QTPRODDESTRE / (100 / (100 + @C_PRODREGRAS_ACRES_VRPEFATCOCPR));
                           END;
                        END;

                        IF @V_IDQTLIQUBRUT = 'B' BEGIN
                           SET @V_QTLIQUIDA = @C_PRODREGRAS_ACRES_QTPRODDESTRE;
                           IF (@C_PRODREGRAS_ACRES_VRPEFATCORPR IS NULL) OR (@C_PRODREGRAS_ACRES_VRPEFATCORPR = 0) BEGIN
                              SET @V_QTBRUTA = @V_QTCALC;
                           END ELSE BEGIN
                              SET @V_QTBRUTA = @V_QTCALC * (100 / (100 - @C_PRODREGRAS_ACRES_VRPEFATCORPR));
                           END;
                        END ELSE BEGIN
                           SET @V_QTBRUTA = @C_PRODREGRAS_ACRES_QTPRODDESTRE;
                           IF (@C_PRODREGRAS_ACRES_VRPEFATCORPR IS NULL) OR (@C_PRODREGRAS_ACRES_VRPEFATCORPR = 0) BEGIN
                              SET @V_QTLIQUIDA = @V_QTCALC;
                           END ELSE BEGIN
                              SET @V_QTLIQUIDA = @V_QTCALC / (100 / (100 - @C_PRODREGRAS_ACRES_VRPEFATCORPR));
                           END;
                        END;

                        IF (@C_PRODREGRAS_ACRES_VRPEFATNUTPR IS NULL) OR (@C_PRODREGRAS_ACRES_VRPEFATNUTPR = 0) BEGIN
                           SET @V_QTCALCNUT = @V_QTLIQUIDA;
                        END ELSE BEGIN
                           SET @V_QTCALCNUT = (@V_QTLIQUIDA * @C_PRODREGRAS_ACRES_VRPEFATNUTPR) / 100;
                        END;

                        INSERT INTO RECEFILI
                           (CDFILAUXPRAT,
                            CDPRATO,
                            CDFILIAL,
                            CDPRODUTO,
                            QTPRODRECLOC, /*Quantidade lquida*/
                            VRPEFATCOCLO,
                            VRPEFATCORLO,
                            HRTEMPPREPLO,
                            SGUNIDADE,
                            QTUNIDESTLO,
                            QTBRUTALO,    /*Quantidade requerida*/
                            IDPRODBASELO,
                            DTULTATURECF,
                            VRPEFATNUTLO,
                            QTCALCNUTRLO,
                            QTBRUTALOUNR) /*Quantidade bruta*/
                        VALUES
                           (@V_P,
                            @C_PRODREGRAS_ACRES_CDPRATO,
                            @CUR_FILIAL,
                            @C_PRODREGRAS_ACRES_CDPRODDESTRE,
                            @V_QTLIQUIDA,
                            @C_PRODREGRAS_ACRES_VRPEFATCOCPR,
                            @C_PRODREGRAS_ACRES_VRPEFATCORPR,
                            @C_PRODREGRAS_ACRES_HRTEMPPREPPR,
                            @C_PRODREGRAS_ACRES_SGUNIDADE,
                            @V_QTBRUTA,/*Deve ser igual a quantidade requerida*/
                            @V_QTBRUTA,
                            @C_PRODREGRAS_ACRES_IDPRODBASEPR,
                            GETDATE(),
                            @C_PRODREGRAS_ACRES_VRPEFATNUTPR,
                            @V_QTCALCNUT,
                            @V_QTBRUTA);
                     END;

                     FETCH NEXT FROM C_PRODREGRAS_ACRES INTO @C_PRODREGRAS_ACRES_CDPRATO,      @C_PRODREGRAS_ACRES_CDPRODUTO,
                                                             @C_PRODREGRAS_ACRES_QTPRODPRAT,   @C_PRODREGRAS_ACRES_VRPEFATCOCPR,
                                                             @C_PRODREGRAS_ACRES_VRPEFATCORPR, @C_PRODREGRAS_ACRES_HRTEMPPREPPR,
                                                             @C_PRODREGRAS_ACRES_SGUNIDADE,    @C_PRODREGRAS_ACRES_QTUNIDESTPR,
                                                             @C_PRODREGRAS_ACRES_QTBRUTAPR,    @C_PRODREGRAS_ACRES_IDPRODBASEPR,
                                                             @C_PRODREGRAS_ACRES_VRPEFATNUTPR, @C_PRODREGRAS_ACRES_QTCALCNUTRPR,
                                                             @C_PRODREGRAS_ACRES_QTBRUTAPRUNR, @C_PRODREGRAS_ACRES_CDPRODDESTRE,
                                                             @C_PRODREGRAS_ACRES_QTPRODDESTRE;
                  END;

                  CLOSE C_PRODREGRAS_ACRES;
                  DEALLOCATE C_PRODREGRAS_ACRES;

                  /*RETORNA OS PRODUTOS QUE EXISTAM NA RECEPADR, EXISTAM NA REGRAS COM QUANTIDADE ZERO E
                    QUE O PRODUTO DE ORIGEM E DESTINO NO EXISTA NA RECEFILI*/
                  DECLARE C_PRODREGRAS_ACRESZERO CURSOR FOR
                     SELECT
                        RP.CDPRATO,
                        RP.CDPRODUTO,
                        RP.QTPRODPRAT,
                        RP.VRPEFATCOCPR,
                        RP.VRPEFATCORPR,
                        RP.HRTEMPPREPPR,
                        RP.SGUNIDADE,
                        RP.QTUNIDESTPR,
                        RP.QTBRUTAPR,
                        RP.IDPRODBASEPR,
                        RP.VRPEFATNUTPR,
                        RP.QTCALCNUTRPR,
                        RP.QTBRUTAPRUNR,
                        R.CDPRODDESTRE,
                        R.QTPRODDESTRE
                     FROM
                        PRODUTO P,
                        RECEPADR RP LEFT JOIN PRODFILI PF ON
                                         @CUR_FILIAL  = PF.CDFILIAL AND
                                         RP.CDPRODUTO = PF.CDPRODUTO,
                        REGRAREVRECE R
                     WHERE
                        RP.CDPRODUTO                      = P.CDPRODUTO       AND
                        ISNULL(PF.IDCNTRESTOQ, @V_S)      = @V_S              AND
                        ISNULL(PF.IDPRODATIV, @V_A)       = @V_A              AND
                        P.IDPRODATIVPR                    = @V_S              AND
                        RP.CDFILAUXPRAT                   = @V_P              AND
                        RP.CDPRATO                        = @CUR_PRATO        AND
                        R.CDFILIAL                        = @CUR_FILIAL       AND
                        R.IDAPLICAREG                     = @V_S              AND
                        R.CDPRODDESTRE IS NOT NULL                            AND
                        R.CDPRODORIGRE                    = RP.CDPRODUTO      AND
                        R.QTPRODORIGRE                    = 0                 AND
                        ISNULL(RP.SGUNIDADE, P.SGUNIDADE) = P.SGUNIDADE       AND
                        NOT EXISTS (SELECT
                                       R.CDPRODORIGRE
                                    FROM
                                       PRODUTO P,
                                       RECEPADR RC LEFT JOIN PRODFILI PF ON
                                                        @CUR_FILIAL  = PF.CDFILIAL AND
                                                        RC.CDPRODUTO = PF.CDPRODUTO,
                                       REGRAREVRECE R
                                    WHERE
                                       RC.CDPRODUTO                      = P.CDPRODUTO   AND
                                       ISNULL(PF.IDCNTRESTOQ, @V_S)      = @V_S          AND
                                       ISNULL(PF.IDPRODATIV, @V_A)       = @V_A          AND
                                       P.IDPRODATIVPR                    = @V_S          AND
                                       RC.CDFILAUXPRAT                   = @V_P          AND
                                       RC.CDPRATO                        = @CUR_PRATO    AND
                                       R.CDFILIAL                        = @CUR_FILIAL   AND
                                       R.IDAPLICAREG                     = @V_S          AND
                                       R.CDPRODORIGRE                    = RC.CDPRODUTO  AND
                                       R.QTPRODORIGRE = CASE @V_IDQTLIQUBRUT WHEN 'B' THEN ROUND(RC.QTPRODPRAT, 5) ELSE ROUND(RC.QTBRUTAPRUNR, 5) END AND
                                       ISNULL(RC.SGUNIDADE, P.SGUNIDADE) = P.SGUNIDADE   AND
                                       R.CDPRODORIGRE                    = RP.CDPRODUTO) AND
                        NOT EXISTS (SELECT RF.CDPRODUTO
                                    FROM   RECEFILI RF
                                    WHERE  RF.CDFILIAL     = @CUR_FILIAL     AND
                                           RF.CDFILAUXPRAT = @V_P            AND
                                           RF.CDPRATO      = @CUR_PRATO      AND
                                           RF.CDPRODUTO    = R.CDPRODORIGRE) AND
                        NOT EXISTS (SELECT RF.CDPRODUTO
                                    FROM   RECEFILI RF
                                    WHERE  RF.CDFILIAL     = @CUR_FILIAL AND
                                           RF.CDFILAUXPRAT = @V_P        AND
                                           RF.CDPRATO      = @CUR_PRATO  AND
                                           RF.CDPRODUTO    = R.CDPRODDESTRE)
                     ORDER BY P.CDARVPROD

                  OPEN C_PRODREGRAS_ACRESZERO;
                  FETCH NEXT FROM C_PRODREGRAS_ACRESZERO INTO @C_PRODREGRAS_ACRESZERO_CDPRATO,      @C_PRODREGRAS_ACRESZERO_CDPRODUTO,
                                                              @C_PRODREGRAS_ACRESZERO_QTPRODPRAT,   @C_PRODREGRAS_ACRESZERO_VRPEFATCOCPR,
                                                              @C_PRODREGRAS_ACRESZERO_VRPEFATCORPR, @C_PRODREGRAS_ACRESZERO_HRTEMPPREPPR,
                                                              @C_PRODREGRAS_ACRESZERO_SGUNIDADE,    @C_PRODREGRAS_ACRESZERO_QTUNIDESTPR,
                                                              @C_PRODREGRAS_ACRESZERO_QTBRUTAPR,    @C_PRODREGRAS_ACRESZERO_IDPRODBASEPR,
                                                              @C_PRODREGRAS_ACRESZERO_VRPEFATNUTPR, @C_PRODREGRAS_ACRESZERO_QTCALCNUTRPR,
                                                              @C_PRODREGRAS_ACRESZERO_QTBRUTAPRUNR, @C_PRODREGRAS_ACRESZERO_CDPRODDESTRE,
                                                              @C_PRODREGRAS_ACRESZERO_QTPRODDESTRE;

                  WHILE (@@FETCH_STATUS = 0) BEGIN
                     SELECT @V_PROD_JA_EXISTE = MAX(CDPRODUTO)
                     FROM   RECEFILI
                     WHERE  CDFILIAL     = @CUR_FILIAL AND
                            CDPRATO      = @CUR_PRATO  AND
                            CDFILAUXPRAT = @V_P        AND
                            CDPRODUTO    = @C_PRODREGRAS_ACRESZERO_CDPRODDESTRE;
                     IF @V_PROD_JA_EXISTE IS NULL BEGIN
                        /*SE GERAR EXCEO, ENTO O PRODUTO NO EXISTE NA RECEFILI E PODE SER INSERIDO*/
                        IF @C_PRODREGRAS_ACRESZERO_QTPRODDESTRE <> 0 BEGIN
                           SET @V_QTLIQUIDA = 0;
                           SET @V_QTBRUTA   = 0;
                           SET @V_QTCALC    = 0;
                           SET @V_QTCALCNUT = 0;

                           IF (@C_PRODREGRAS_ACRESZERO_VRPEFATCOCPR IS NULL) OR (@C_PRODREGRAS_ACRESZERO_VRPEFATCOCPR = 0) BEGIN
                              SET @V_QTCALC = @C_PRODREGRAS_ACRESZERO_QTPRODDESTRE;
                           END ELSE BEGIN
                              IF @V_IDQTLIQUBRUT = 'B' BEGIN
                                 SET @V_QTCALC = @C_PRODREGRAS_ACRESZERO_QTPRODDESTRE * (100 / (100 + @C_PRODREGRAS_ACRESZERO_VRPEFATCOCPR));
                              END ELSE BEGIN
                                 SET @V_QTCALC = @C_PRODREGRAS_ACRESZERO_QTPRODDESTRE / (100 / (100 + @C_PRODREGRAS_ACRESZERO_VRPEFATCOCPR));
                              END;
                           END;

                           IF @V_IDQTLIQUBRUT = 'B' BEGIN
                              SET @V_QTLIQUIDA = @C_PRODREGRAS_ACRESZERO_QTPRODDESTRE;
                              IF (@C_PRODREGRAS_ACRESZERO_VRPEFATCORPR IS NULL) OR (@C_PRODREGRAS_ACRESZERO_VRPEFATCORPR = 0) BEGIN
                                 SET @V_QTBRUTA = @V_QTCALC;
                              END ELSE BEGIN
                                 SET @V_QTBRUTA = @V_QTCALC * (100 / (100 - @C_PRODREGRAS_ACRESZERO_VRPEFATCORPR));
                              END;
                           END ELSE BEGIN
                              SET @V_QTBRUTA = @C_PRODREGRAS_ACRESZERO_QTPRODDESTRE;
                              IF (@C_PRODREGRAS_ACRESZERO_VRPEFATCORPR IS NULL) OR (@C_PRODREGRAS_ACRESZERO_VRPEFATCORPR = 0) BEGIN
                                 SET @V_QTLIQUIDA = @V_QTCALC;
                              END ELSE BEGIN
                                 SET @V_QTLIQUIDA = @V_QTCALC / (100 / (100 - @C_PRODREGRAS_ACRESZERO_VRPEFATCORPR));
                              END;
                           END;

                           IF (@C_PRODREGRAS_ACRESZERO_VRPEFATNUTPR IS NULL) OR (@C_PRODREGRAS_ACRESZERO_VRPEFATNUTPR = 0) BEGIN
                              SET @V_QTCALCNUT = @V_QTLIQUIDA;
                           END ELSE BEGIN
                              SET @V_QTCALCNUT = (@V_QTLIQUIDA * @C_PRODREGRAS_ACRESZERO_VRPEFATNUTPR) / 100;
                           END;
                        END ELSE BEGIN
                           SET @V_QTLIQUIDA = @C_PRODREGRAS_ACRESZERO_QTPRODPRAT;
                           SET @V_QTBRUTA   = @C_PRODREGRAS_ACRESZERO_QTBRUTAPR;
                           SET @V_QTCALCNUT = @C_PRODREGRAS_ACRESZERO_QTCALCNUTRPR;
                        END;
                        INSERT INTO RECEFILI
                           (CDFILAUXPRAT,
                            CDPRATO,
                            CDFILIAL,
                            CDPRODUTO,
                            QTPRODRECLOC, /*Quantidade lquida*/
                            VRPEFATCOCLO,
                            VRPEFATCORLO,
                            HRTEMPPREPLO,
                            SGUNIDADE,
                            QTUNIDESTLO,
                            QTBRUTALO,    /*Quantidade requerida*/
                            IDPRODBASELO,
                            DTULTATURECF,
                            VRPEFATNUTLO,
                            QTCALCNUTRLO,
                            QTBRUTALOUNR) /*Quantidade bruta*/
                        VALUES
                           (@V_P,
                            @C_PRODREGRAS_ACRESZERO_CDPRATO,
                            @CUR_FILIAL,
                            @C_PRODREGRAS_ACRESZERO_CDPRODDESTRE,
                            @V_QTLIQUIDA,
                            @C_PRODREGRAS_ACRESZERO_VRPEFATCOCPR,
                            @C_PRODREGRAS_ACRESZERO_VRPEFATCORPR,
                            @C_PRODREGRAS_ACRESZERO_HRTEMPPREPPR,
                            @C_PRODREGRAS_ACRESZERO_SGUNIDADE,
                            @V_QTBRUTA,/*Deve ser igual a quantidade requerida*/
                            @V_QTBRUTA,
                            @C_PRODREGRAS_ACRESZERO_IDPRODBASEPR,
                            GETDATE(),
                            @C_PRODREGRAS_ACRESZERO_VRPEFATNUTPR,
                            @V_QTCALCNUT,
                            @V_QTBRUTA);
                     END;
                     FETCH NEXT FROM C_PRODREGRAS_ACRESZERO INTO @C_PRODREGRAS_ACRESZERO_CDPRATO,      @C_PRODREGRAS_ACRESZERO_CDPRODUTO,
                                                                 @C_PRODREGRAS_ACRESZERO_QTPRODPRAT,   @C_PRODREGRAS_ACRESZERO_VRPEFATCOCPR,
                                                                 @C_PRODREGRAS_ACRESZERO_VRPEFATCORPR, @C_PRODREGRAS_ACRESZERO_HRTEMPPREPPR,
                                                                 @C_PRODREGRAS_ACRESZERO_SGUNIDADE,    @C_PRODREGRAS_ACRESZERO_QTUNIDESTPR,
                                                                 @C_PRODREGRAS_ACRESZERO_QTBRUTAPR,    @C_PRODREGRAS_ACRESZERO_IDPRODBASEPR,
                                                                 @C_PRODREGRAS_ACRESZERO_VRPEFATNUTPR, @C_PRODREGRAS_ACRESZERO_QTCALCNUTRPR,
                                                                 @C_PRODREGRAS_ACRESZERO_QTBRUTAPRUNR, @C_PRODREGRAS_ACRESZERO_CDPRODDESTRE,
                                                                 @C_PRODREGRAS_ACRESZERO_QTPRODDESTRE;
                  END;

                  CLOSE C_PRODREGRAS_ACRESZERO;
                  DEALLOCATE C_PRODREGRAS_ACRESZERO;


               END;

               SET @V_CONTRECEF = 0;
               SELECT @V_CONTRECEF = COUNT(*)
               FROM  PRATFILI
               WHERE CDPRATO      = @CUR_PRATO AND
                     CDFILAUXPRAT = @V_P       AND
                     CDFILIAL     = @CUR_FILIAL;

               IF (@V_CONTRECEF > 0) BEGIN
                  DELETE FROM PRATFILI
                  WHERE
                     CDPRATO      = CDPRATO AND
                     CDFILAUXPRAT = @V_P    AND
                     CDFILIAL     = @CUR_FILIAL;

                  INSERT INTO PRATFILI
                     (CDFILAUXPRAT,
                      CDPRATO,
                      CDFILIAL,
                      NRCORPRIFILI,
                      NRCORSEQFILI,
                      NRCORAUXFILI,
                      QTPADRAOFILI,
                      QTCONTAIFILI,
                      HRVALCONFILI,
                      NMFANTASIAPF,
                      QTCARBOPRFIL,
                      QTLIPIDPRFIL,
                      QTPROTEPRFIL,
                      QTCALORPRFIL,
                      QTALCOOPRFIL)
                  (SELECT
                      PT.CDFILAUXPRAT,
                      PT.CDPRATO,
                      RF.CDFILIAL,
                      PT.NRCORPRIPRAT,
                      PT.NRCORSEQPRAT,
                      PT.NRCORAUXPRAT,
                      SUM(QTPRODRECLOC) AS QTPRODRECLOC,
                      PT.QTCONTAIPRAT,
                      PT.HRVALCONPRAT,
                      PT.NMFANTASIAPR,
                      PT.QTCARBOPRPAD,
                      PT.QTLIPIDPRPAD,
                      PT.QTPROTEPRPAD,
                      PT.QTCALORPRPAD,
                      PT.QTALCOOPRPAD
                   FROM
                      PRATPADR PT,
                      RECEFILI RF
                   WHERE
                      PT.CDFILAUXPRAT = @V_P            AND
                      PT.CDPRATO      = @CUR_PRATO      AND
                      RF.CDFILIAL     = @CUR_FILIAL     AND
                      RF.CDFILAUXPRAT = PT.CDFILAUXPRAT AND
                      RF.CDPRATO      = PT.CDPRATO
                   GROUP BY
                      PT.CDFILAUXPRAT,
                      PT.CDPRATO,
                      RF.CDFILIAL,
                      PT.NRCORPRIPRAT,
                      PT.NRCORSEQPRAT,
                      PT.NRCORAUXPRAT,
                      PT.QTCONTAIPRAT,
                      PT.HRVALCONPRAT,
                      PT.NMFANTASIAPR,
                      PT.QTCARBOPRPAD,
                      PT.QTLIPIDPRPAD,
                      PT.QTPROTEPRPAD,
                      PT.QTCALORPRPAD,
                      PT.QTALCOOPRPAD);
               END;
            END;
         END;
         FETCH NEXT FROM C_FILIAISAGREG INTO @CUR_FILIAL;
      END; /*FILIAIS AGREGADAS*/
      CLOSE C_FILIAISAGREG;
      DEALLOCATE C_FILIAISAGREG;
      FETCH NEXT FROM C_PRATOSORIG INTO @CUR_PRATO;
   END; /*PRATOS*/
   CLOSE C_PRATOSORIG;
   DEALLOCATE C_PRATOSORIG;
END;
GO

-- VERSAO --
EXEC ATUVEROBJ 'INTEGRA_RECEITA_REGRAS','5.01.002';
GO
